# 说明

此脚本专用于**中山大学珠海校区羽毛球场**的预定，理论上更改文件中的部分参数可实现预定其他场地，请自行测试

# 使用步骤

## 安装

```shell
python -m pip install --upgrade sysubadminton
```

## 修改配置文件

新建 `config.ini`，填入想要的配置，以及用户名和密码

```ini
[badminton]
; 下面写入希望预定的场地，按顺序进行预定，如 1, 2, 3
stock_name = 7, 8, 6, 9, 4, 3, 2, 1, 5

; 下面写入需要预定的时间，按顺序进行预定，如希望预定 16-17, 17-18 时，写入 16, 17
stock_time = 19, 20, 18, 17

; 下面写入预定的日期，如 2020-12-04，留空为程序运行日期的后天（T+2），通常留空即可
stock_date =

; 下面写入预定的顺序，如果优先满足场地，即尽可能订同一场地的不同时间段，则输入 name
; 如果优先满足时间，即尽可能订同一时间段的不同场地，则输入 time
first = name

; 下面写入每个时间段需要的场地数，默认不限制
stock_number = 99

netid =
password =
```

## 运行脚本

```shell
badminton config.ini
```

查看完整指令

```shell
badminton -h
```

可自行指定开始预订时间等。

验证码识别顺利的话即可自动登录，到时间订场。

PS. 此脚本目测可以实现晚上打开，早上自动订场，Linux 下可配合 `screen` 使用。如果对验证码自动识别放心的话，可以设置定时任务运行。
